async fn preload_parquet_meta_cache_for_files(
region_id: RegionId,
cache_manager: CacheManagerRef,
sst_meta_cache_capacity: u64,
table_dir: String,
path_type: PathType,
object_store: ObjectStore,
files: Vec<FileHandle>,
) -> usizeExpand description
Preloads Parquet metadata into the in-memory SST meta cache on region open.
This improves the latency of the first query after server start by avoiding large Parquet metadata reads on demand.
The preload is best-effort:
- Always tries to warm from the local write cache (file cache) first.
- If the region storage backend is local filesystem (
Scheme::Fs), it may also load metadata directly from the local store. - It will not fetch metadata from remote object stores (S3/GCS/OSS/…).